use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( examples lib script t xt ) );
__DATA__
APIs
Acklam
Astronomy
Avis
Ben
Brian
Christiansen
Council
Dagfinn
David
EXLOCK
Ed
Etheridge
File
Gim
Golden
Guillem
III
Ilmari
Ivy
James
Jenness
John
Jover
Karen
Keenan
Kevin
Mannsåker
Mengué
Mowrey
NFS
Nicolas
Olivier
OpenBSD
POSIX
Particle
Peter
Physics
Rabbitson
Research
Rezic
Roy
Ryde
Slaven
Steinbrunner
TMPDIR
Temp
Tilly
Tim
TopSystemUID
UK
UNLINK
VMS
Yee
and
atoomic
brian
btilly
chdir'ed
cmpstat
dagolden
destructor
dirname
dolmen
dsteinbrunner
eda
endeavour
et
ether
guillem
ilmari
irc
isa
jenness
jkeen
lib
mohawk2
newdir
numifies
pjacklam
ribasushi
rivy
srezic
the
tim
tjenness
unix
unlink
unlinked
unlinking
user42
